R6 Class for analysing sequence sets with accompanying temporal data
Source:R/temporal_set.R
TemporalSet.RdR6 Class for analysing sequence sets with accompanying temporal data
R6 Class for analysing sequence sets with accompanying temporal data
Super class
floundeR::FloundeR -> TemporalSet
Methods
Method new()
Initialise a new instance of the R6 Class TemporalSet
Usage
TemporalSet$new(seqsum = NA)Method runtime()
get a rounded runtime from temporal information in sequencing summary
The sequencing summary file contains information on pore dwell time and start time for given sequencing reads. An analysis of the start time information can be used to calculate a canonical sequencing run time that is rounded to key temporal breaks.
Method run_yield()
Prepare summary statistics that describe a flowcell run's yield
A flowcell can yield both sequence bases and sequence reads and the acquisition of these data has a temporal element. This method is used to summarise run performance through assessment of yield per unit time.
Arguments
resolutiondescribes the temporal resolution (in minutes) by which yield will be summarised.
basesa logical that describes whether the method will summarise sequence reads or sequence bases - (TRUE) for bases by default
cumulativedefines whether the number of reads(bases) per bin is described as actual number or as a temporally cumulative number
Method feature_over_time()
Report a binned temporal data facet (such as speed, quality, length)
The temporal sequencing information can be used to summarise other data facets in a time dependent manner to address questions such as whether there is a change in sequencing speed, length or quality over time.
Arguments
resolutiondescribes the temporal resolution (in minutes) by which yield will be summarised (60 minutes by default).
passesis a logical that defines whether the plot should present data that has passed or failed QC - (TRUE) by default to select for only the QC passed sequence reads.
featuredefines the feature to summarise (speed by default) but could include e.g.
sequence_length_templateormean_qscore_template.
Method t50()
calculate T50 timepoint at which 50% of sequence reads are obtained
Temporal data and yield data can be used to identify timepoints at which a given fraction of the data has been obtained.
Arguments
passesis a logical that defines that we should focus only on the passed QC reads (TRUE by default) - should probably be deprecated since asking for T50 of failed reads is just silly?
tis the fractional timepoint (0.5 by default) where we are interested in knowing the time at which this fraction of reads was obtained.