A collection of files are distributed with the floundeR package; this accessory method is aimed to abbreviate the technical code for the identification of these files and to clean the vignettes and code examples.
A collection of files are distributed with the floundeR package; this accessory method is aimed to abbreviate the technical code for the identification of these files and to clean the vignettes and code examples.