This method is intended to streamline the usage of floundeR in more coherent workflows through the enabling of more magrittr-like piped commands. This method will consume floundeR specified classes and return a flowcell object where possible.
Examples
SequencingSummary$new(flnDr("sequencing_summary.txt.bz2")) %>% to_flowcell()
#> Preparing channel count information
#> <floundeR::Flowcell>