R6 Class for describing additional Angenieux decorations
Source:R/angenieux.R
AngenieuxDecoration.RdR6 Class for describing additional Angenieux decorations
R6 Class for describing additional Angenieux decorations
Super class
floundeR::FloundeR -> AngenieuxDecoration
Public fields
decorationThis field contains the decoration that will be applied to the Angenieux object
Methods
Method new()
This is the constructor for the AngenieuxDecoration object
Usage
AngenieuxDecoration$new(decoration_type, ...)Method .add_vlegend()
Add a legend text to accompany a vertical line
Usage
AngenieuxDecoration$.add_vlegend(
xintercept,
colour = "green",
legend = "",
hjust = 0,
vjust = 1,
size = 6
)Arguments
xinterceptthe point at which the vertical line will intercept the x-axis
colourthe colour of the line
legendthe text to display at the given location
hjusthorizonal justify (0=left, 1=right)
vjustvertical justify (0=bottom, 1=top)
sizethe size of the font to present at the given location
Method .add_ggplot2()
Just add some plain ggplot2 to the AngenieuxDecoration and layer on to
the Angenieux plot - this is for the lazy hacking out and visualisation
of plots