R6 Class for loading and analysing BLAST results in basic Pairwise format
Source: R/ncbi_blast.R
Blast.RdBLAST results are a fundamental unit of basic comparative genomics. This R6 object has been implemented for the systematic exploration of BLAST results within the scope of the Lodestar project.
Super class
floundeR::FloundeR -> Blast
Methods
Method new()
Creates a new Blast object. This initialisation method performs other sanity checking of the defined file(s) to ensure that it is indeed parseable and creates the required data structures.
Usage
Blast$new(blast_file)Method count()
Return the number of BLAST results that are contained within the BLAST file provided.
Examples
## ------------------------------------------------
## Method `Blast$new`
## ------------------------------------------------
blast_results <- flnDr("drosophila_uniref100.blastx.txt")
blast <- Blast$new(blast_file=blast_results)
#> → Parsing BLAST result file [drosophila_uniref100.blastx.txt]