This class aims to simplify the handling and exploration of FASTQ files and provides simple methods for accessing information that can be used to assess the contents of a FASTQ file.
Super class
floundeR::FloundeR -> Fastq
Active bindings
sequencingsetThe
sequencingsetactive binding returns a sequencingset object that is canonically structured around thepasses_filteringlogical field to allow assessment of sequencing characteristics.
Methods
Method new()
Creates a new Fastq object. This initialisation method performs other sanity checking of the defined file(s) to ensure that it is indeed parseable and creates the required data structures.
Usage
Fastq$new(fastq_file)Method as_tibble()
Export the imported dataset(s) as a tibble
This object consumes a sequencing summary file (and optionally the corresponding barcoding_summary file) and creates an object in memory that can be explored, sliced and filtered. This method dumps out the in-memory object for further exploration and development.
Method sequence_chunks()
Split the fastq sequence file explored by the package into sequence chunks for e.g. import into a relational database.
Method get_sequence_chunk()
Get a chunk of fastq sequences from a larger monolithic file. This method
can be called for up to $sequence_chunks() times or until NULL results
are returned.
Examples
## ------------------------------------------------
## Method `Fastq$new`
## ------------------------------------------------
canonical_fastq <- flnDr("example.fastq.gz")
fastq <- Fastq$new(canonical_fastq)
#> → opening fastq stream