This is an overarching class which other flounder classes are expected to
inherit from. The floundeR object contains methods and variables that are
maintained for other objects - there is probably not a sensible usecase for
actually creating a floundeR instance on its own.
Methods
Method print()
this print method overrides the standard print function as included with R6 objects - this is to better define what is contained within an object and to provide better floundeR abstraction
Method bin_data()
general method for binning continuous data into sensible bins - used by various methods within the broader floundeR framework.
Method num_scale()
scale numerics in bases into kilo/mega/giga etc measurements for e.g. plots and other graphic visualisations