This class aims to simplify the handling and exploration of Flowcell based data and contains various presets, designs and visualisation tools required for assessing flowcell performance and metrics.
Super class
floundeR::FloundeR -> Flowcell
Active bindings
platformHave a guess at the most likely flowcell platform used
The sequencing summary file contains no information on the sequencing device or flowcell used. For the preparation of channel density maps it is worth considering which flowcell type is most likely to have been used - this can be guessed on the number of channels described within the data
density_dataproduce channelMap for spatial plots
prepares a matrix of X, Y coordinates and the corresponding readcount information for the type of flowcell predicted by
get_flowcell_platform
Methods
Method new()
Creates a new Flowcell object. This initialisation method performs other sanity checking of the defined file(s) and creates the required data structures.
Usage
Flowcell$new()Method set_channel_counts()
set channel count summary information
This method is used to provide primitive channel count information for the number of total reads that have been observed per channel - this is used for the generation of spatial plots
Method as_tibble()
Export the imported dataset(s) as a tibble
This object consumes a sequencing summary file (and optionally the corresponding barcoding_summary file) and creates an object in memory that can be explored, sliced and filtered. This method dumps out the in-memory object for further exploration and development.