R6 Class for loading and analysing Genbank whole genome files
Source:R/genbank_genome.R
GenbankGenome.RdThis class aims to implement a couple of trivial methods for wrangling whole microbial genome information from Genbank files
Super class
floundeR::FloundeR -> GenbankGenome
Methods
Method new()
Creates a new GenbankGenome object. This initialisation method performs minimal sanity checking of the defined file(s)
Usage
GenbankGenome$new(gb_file)Examples
TB_reference = flnDr("TB_H37Rv.gb.gz")
tb <- GenbankGenome$new(TB_reference)Method list_cds()
exports the annotated genomic features as a GenomicRanges object. This can be used for the review of content in a genomics context.
Method get_cds()
Get the CDS information for one or more annotated features from the genome of interest.
Examples
## ------------------------------------------------
## Method `GenbankGenome$new`
## ------------------------------------------------
TB_reference = flnDr("TB_H37Rv.gb.gz")
tb <- GenbankGenome$new(TB_reference)
#> ℹ Parsing genbank file [/private/var/folders/g5/kp9259xj7778b2kzcmym7jd00000gn/T/RtmpfBxQW1/temp_libpath10eeb6d0106e7/floundeR/extdata/TB_H37Rv.gb.gz]
#> → processing sequence [73527] lines
#> → setting sequence
#> ✔ Done! [213179] lines parsed