R6 Class for loading and analysing sequence sets
R6 Class for loading and analysing sequence sets
Super class
floundeR::FloundeR -> Infographic
Public fields
panel.widthdefines width of an infographic block
panel.heightdefines height of an infographic block
panel.spacerdefines spacing around an infographic block
panel.x.offsetdefines x offset spacing for whole graphic
panel.y.offsetdefines y offset spacing for whole graphic
columnsdefines the number of columns to use in infographic plot
Active bindings
itemsreturn an integer describing the number of items that is contained within the
Infographic.
Methods
Method display_fa()
Display a collection of fontawesome based infographics for picking.
The fontawesome collection of icons contains over 700 icons of
which some are more useful / desirable than others. This accessory
method is used to render an Infographic report that summarised the
available icons within a predefined range - the intention here is to
make the selection of fonts to use in infographics a little simpler
and easier. This replaces a dodgy notebook approach that was used
previously.