R6 Class for loading and analysing sequence sets
R6 Class for loading and analysing sequence sets
Super class
floundeR::FloundeR -> SequencingSet
Active bindings
enumerateprepares a simple
1D Angenieuxenumeration of the provided dataset for quick visualisation of the dataset.N50Calculate and return the N50 value for passed quality sequence reads in the current
SequencingSetobjectmeanCalculate and return the mean sequence length for passed quality reads in the
SequencingSetobject
Methods
Method new()
Initialise a new instance of the R6 Class SequencingSet
Usage
SequencingSet$new(keycol, seqsum = NA)Method as_tibble()
Export the imported dataset(s) as a tibble
This object consumes a sequencing summary file (and optionally the corresponding barcoding_summary file) and creates an object in memory that can be explored, sliced and filtered. This method dumps out the in-memory object for further exploration and development.
Method read_length_bins()
bin the sequences in seqsum content into bins of sequence length
The nanopore sequencing run is expected to return a collection of sequences that vary in their length distributions; this variance is a function of the sequencing library prepared, the starting DNA etc. This method is used to bin reads into uniform bins to assess the distribution of sequence lengths.
Usage
SequencingSet$read_length_bins(
normalised = TRUE,
cumulative = FALSE,
bins = 20,
outliers = 0.025
)Arguments
normalisedshould the sequence collection be reported to normalise for the number of sequence bases sequenced or the number of sequence reads - TRUE by default to normalise for sequenced bases.
cumulativedefines whether cumulative sequence bases (reads) are reported per bin (FALSE by default).
binsthe number of sequence bins that should be prepared (20 by default)
outliersdefines the number of outliers (0.025 = 2.5%) that are excluded from the longest reads to prepare a richer distribution visulation - the plots can be bothered by the long tail of mini-whales.
Method quality_bins()
bin the sequences in seqsum content into bins of quality
The nanopore sequencing run is expected to return a collection of sequences that vary in their quality distributions; this variance is a function of the sequencing library prepared, the starting DNA etc. This method is used to bin reads into uniform quality bins to assess the overall quality of the run and to identify potential issues